=====
PySim
=====

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |travis| |appveyor|

.. |travis| image:: https://travis-ci.org/aldebjer/pysim.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/aldebjer/pysim

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/github/aldebjer/pysim?branch=master&svg=true
    :alt: AppVeyor Build Status
    :target: https://ci.appveyor.com/project/aldebjer/pysim

.. end-badges

Pysim is a tool for modeling and simulation of dynamical systems. The systems are described by ordinary differential
equations. There are a number of systems included, and more systems can be added.

For more information on how to use it, build it and extend it please see the
homepage at:

http://pys.im

or the documentation at: 

http://pys.im/doc

